clc
clear

% % MINIMIZATION PROBLEM: KL FIRST-PRICE AND COMMON-VALUE AUCTION
% % -------------------------------------------------------------

% % (This program consists of a random search of initial values repeated "e" times, 
% % then the best initial values are selected and the minimization problem is done "i" times,
% % choosing at the very end the estimation that yields the maximum likelihood over the "i" iterations of the process.

% % Comment the specification you are not considering (ONE PRECISION or TYPE-SPECIFIC PRECISION) 

% % SPECIFICATION: ONE PRECISION
% % ----------------------------

% % Random initial valuation:
% % -------------------------

for i=1:3;
for e=1:1000;

inalpha1=rand(1);
inalpha2=(1-inalpha1)*rand(1);
inalpha3=(1-inalpha1-inalpha2)*rand(1);
inlambda=rand(1)*30;

initialvalues(:,e)=[inalpha1; inalpha2; inalpha3; inlambda];

feval(e,i)=LLAuction1(initialvalues(:,e));
end;

minfv(1,i)=min(feval(:,i));
mininitialval(:,i)=[0; 0; 0; 0];

for e=1:1000;
if minfv(1,i)==feval(e,i);
mininitialval(:,i)=initialvalues(:,e);
else;
mininitialval(:,i)=mininitialval(:,i);
end;
end;

minfv(1,i);
mininitialval(:,i);

[U, fval, exitflag, output]=fmincon('LLAuction1', mininitialval(:,i),...
[1 1 1 0], [1], [], [], [0; 0; 0; 0], [1; 1; 1; 100]);

minfvaluation(1,i)=fval;
estimation(:,i)=U;

end;

initialvalues=[minfv; mininitialval]
allestimation=[minfvaluation; estimation]

finalminf=min(minfvaluation);
finalestimation=[0; 0; 0; 0];
minLL=0;

for j=1:3;
if minfvaluation(1,j)==finalminf;
finalestimation=estimation(:,j);
minLL=minfvaluation(1,j);
else;
finalestimation=finalestimation;
minLL=minLL;
end;
end;
minLL
finalestimation

% % SPECIFICATION: TYPE-SPECIFIC PRECISION
% % --------------------------------------

% % Random initial valuation:
% % -------------------------

for i=1:3;
for e=1:1000;

inalpha1=rand(1);
inalpha2=(1-inalpha1)*rand(1);
inalpha3=(1-inalpha1-inalpha2)*rand(1);
inlambda1=rand(1)*300;
inlambda2=rand(1)*300;
inlambda3=rand(1)*300;
inlambda4=rand(1)*30;

initialvalues(:,e)=[inalpha1; inalpha2; inalpha3; inlambda1; inlambda2; inlambda3; inlambda4];
feval(e,i)=LLAuction1(initialvalues(:,e));
end;

minfv(1,i)=min(feval(:,i));
mininitialval(:,i)=[0; 0; 0; 0; 0; 0; 0];

for e=1:1000;
if minfv(1,i)==feval(e,i);
mininitialval(:,i)=initialvalues(:,e);
else;
mininitialval(:,i)=mininitialval(:,i);
end;
end;

minfv(1,i)
mininitialval(:,i)

[U, fval, exitflag, output]=fmincon('LLAuction1', mininitialval(:,i),...
[1 1 1 0 0 0 0], [1], [], [], [0; 0; 0; 0; 0; 0; 0], [1; 1; 1; 400; 400; 400; 50]);
minfvaluation(1,i)=fval;
estimation(:,i)=U;

end;

initialvalues=[minfv; mininitialval]
allestimation=[minfvaluation; estimation]

finalminf=min(minfvaluation)
finalestimation=[0; 0; 0; 0; 0; 0; 0];
minLL=0;

for j=1:3;
if minfvaluation(1,j)==finalminf;
finalestimation=estimation(:,j);
minLL=minfvaluation(1,j);
else;
finalestimation=finalestimation;
minLL=minLL;
end;
end;
minLL
finalestimation